@@ -23,6 +23,8 @@ private:
         Source::SearchDetails details;
         QVector<Source::Result> results;
         int currentPage;
+        int totalSearches;
+        int finishedSearches;
     };
 
     void addNumbers(SearchData* searchData, QString const& data, int index);
