@@ -145,7 +145,7 @@
     <message>
         <location filename="../../gui/detailwindow.cpp" line="160"/>
         <source>Unable to add contact.</source>
-        <translation>Yhteystiedon lisääminen epäonnistui,</translation>
+        <translation>Yhteystiedon lisääminen epäonnistui.</translation>
     </message>
     <message>
         <location filename="../../gui/detailwindow.cpp" line="170"/>
