@@ -49,7 +49,7 @@ private slots:
 
 private:
     void getDetails(QString& street, QString& streetNumber,
-                    QString& zip, QString& city);
+                    QString& zip, QString& city, QString& streetAndNumber);
     QWidget* area_;
     QVBoxLayout* layout_;
     QMaemo5ValueButton* nameButton_;
